/*
 * Konnekt SDK (Software Development Kit)
 * 
 * Nagwek: K.Notify
 * Modyfikowany: 2004-09-27
 * Zgodny z wersj: 
 * Info: Nagwek wtyczki K.Notify.
 * Autor: Kuba Niegowski
 * 
 * rodowisko: Borland C++ i MS Visual C++
 * 
 * http://www.stamina.eu.org/konnekt/sdk/
 * 
 * (C)2002-2003 Stamina
 * SDK suy do przygotowywania oprogramowania wsppracujcego
 * z programem Konnekt. Autorzy nie ponosz adnej odpowiedzialnoci
 * za wykorzystanie tego kodu.
 * Kod zawarty w SDK moe by uywany tylko w projektach dotyczcych
 * programu Konnekt! */


/**
@file Nagwek wtyczki K.Notify wywietlajcej komunikaty nad zegarkiem systemowym.
*/

/** @defgroup KNotify_shared_h Wtyczka K.Notify
  Wtyczka suy do wywietlania informacji w maym, skinowanym okienku
  nad zasobnikiem systemowym.

  Sposb uycia na przykadzie:
  @code
   // Pokae zwyky komunikat...
	Ctrl->IMessage(&KNotify::sIMessage_notify("Hello!"));
   // Pokae komunikat bdu...
	Ctrl->IMessage(&KNotify::sIMessage_notify("Bd!" , 0 , KNotify::sIMessage_notify::tError));
   // Pokae komunikat z ikonk - Logo sieci GG...
	Ctrl->IMessage(&KNotify::sIMessage_notify("Hello!" , UIIcon(IT_LOGO , NET_GG , 0 , 0)));
   // Aby wczy moliwo klikania, trzeba to uruchomi poza konstruktorem
   KNotify::sIMessage_notify notify("Hello!" , UIIcon(IT_LOGO , NET_GG , 0 , 0));
   notify._action = sUIAction(  ); // Oczywicie trzeba poda identyfikatory akcji
   notify._actionParam = 1; // Akcja otrzyma sUIActionNotify_2params::notify1 == 1
   Ctrl->IMessage(&notify);
  @endcode

@{
*/


namespace KNotify {
  const int net = 774;  
	const int icon = 774000; 

  /** Ikonki */
  namespace icons {
    const int inform = 774001;
    const int warning = 774002;
    const int error = 774003;
  }

	/** Akcje wtyczki */
	namespace UI {
		const int gCfg = 774000;
		const int aPrev = 774116;
		const int aExample1 = 774117;
		const int aExample2 = 774118;
		const int aExample3 = 774119;
    const int aOpenWnd =  774120;
	}
	namespace Cfg {
		const int bmp = 774110;
		const int dir = 774115;
		const int status = 774120;
		const int msg = 774121;
		const int delay = 774122;
		const int anim = 774123;
		const int waitclick = 774124;
		const int limit = 774125;
    const int lmbclose = 774126;
    const int fullscreen = 774127;
    const int kinfouse = 774128;
    const int showdescr = 774129;
    const int shwomsgbody = 774130;
    const int showmsglen = 774131;
    const int selfstatus = 774132;
    const int showdescrconn = 774133;
	}

// API zewntrzne
	/** Komunikaty przyjmowane przez wtyczk */
	namespace IM {
		const int show = 774201; /**<  Wywietla informacj nad zegarkiem systemowym. 
                       \return (int) identyfikator uywany do usuwania wiadomoci.
								       @sa KNotify::sIMessage_notify  */
		const int hide = 774202; /**<  Ukrywa informacj  wedug numeru identyfikacyjnego zwracanego podczas wstawiania wiadomoci
                             \param p1 (int) identyfikator */
	}
	/** Pozostawiany tylko dla kompatybilnoci z wczeniejsz wersj. Prosz nie uywa! */
	struct sIMessage_notify_v1: public sIMessage_base {
		char *txt;UINT mask;UINT status;UINT cntnet;HICON ico; 
	};

	/** Struktura do przesyania komunikatu...
	
	Typ ikonki ustawiany jest przez konstruktor.
	Jeeli nie podamy adnej ikonki, K.Notify dobierze jak
	w zalenoci od typu wiadomoci.
	*/
	class sIMessage_notify: public sIMessage_base {
	public:
		const static unsigned char itIcoID = 0; ///< _icoType - uywa _icoID, lub nie podaje ikonki, gdy _icoID jest == 0
		const static unsigned char itHICON = 1; ///< _icoType - uywa _ico
		const static unsigned char tInform = 0; ///< _msgType - Domylny
		const static unsigned char tError = 1; ///< _msgType - Bd
		const static unsigned char tWarning = 2; ///< _msgType - Ostrzeenie
	public:
		const char * _text; ///< Tre komunikatu
		unsigned char _icoType : 4; ///< Typ ikonki @sa itIcoID itHICON
		unsigned char _msgType : 4; ///< Typ komunikatu @sa tInform tError tWarning
		signed   char _timeToLive : 8; ///< Jak dugo komunikat bdzie dostpny, jako wielokrotno wywietlania jednej linijki, lub -1 jeli ma czeka na kliknicie.
		unsigned char _clickable : 8; ///< Czy dziaa action @sa _action
	private:
		unsigned char align__ : 8;
	public:
		/** Ikonka */
		union {
			int _icoID; ///< Identyfikator ikonki. @sa #UIIcon
			HICON _ico; ///< Podajemy uchwyt do Windowsowej ikony.
		};
		sUIAction _action; ///< Akcja do wywoania w momencie kliknicia
    int _actionParam;  ///< Parametr do przekazania razem z #ACTN_ACTION w momencie wywoania _action.
	public:
		/** Przesya wiadomo z identyfikatorem ikonki */
		sIMessage_notify(const char * text , unsigned int icoID , const unsigned char msgType = tInform , unsigned char timeToLive = 1)
			:sIMessage_base(IM::show , KNotify::net , -1) 
			, _text(text) , _icoType(itIcoID) , _icoID(icoID) , _msgType(msgType) , _timeToLive(timeToLive) , _actionParam(0), _clickable(0) 
		{
      s_size=sizeof(sIMessage_notify);
      _action = sUIAction(0,0,-2);
		}
		/** Przesya wiadomo z uchwytem do ikonki */
		sIMessage_notify(const char * text , HICON ico , const unsigned char msgType = tInform , unsigned char timeToLive = 1)
			:sIMessage_base(IM::show , KNotify::net , -1) 
			, _text(text) , _icoType(itHICON), _msgType(msgType) , _timeToLive(timeToLive) , _actionParam(0), _clickable(0) 
		{
      s_size=sizeof(sIMessage_notify);
      _ico = ico; 
      _action = sUIAction(0,0,-2);
		}
		/** Przesya wiadomo jako tInform */
		sIMessage_notify(const char * text)
			:sIMessage_base(IM::show , KNotify::net , -1) 
			, _text(text) , _icoType(0) , _icoID(0), _msgType(tInform) , _timeToLive(1) , _actionParam(0) , _clickable(0)
		{
      s_size=sizeof(sIMessage_notify);
      _action = sUIAction(0,0,-2);
    }

		sIMessage_notify(sIMessage_notify * msg)
			:sIMessage_base(msg) 
    {
      s_size=sizeof(sIMessage_notify);
			if (msg->s_size == sizeof(sIMessage_notify_v1)) { 
				sIMessage_notify_v1 * msg1 = (sIMessage_notify_v1*)msg;
				this->_text = msg1->txt;
				this->_icoType = msg1->mask ? itIcoID : itHICON;
        this->_icoID = msg1->mask == 0 ? (int)msg1->ico : msg1->mask == 1 ? UIIcon(IT_STATUS , msg1->cntnet , msg1->status , 0) : msg1->mask == 2 ? UIIcon(IT_MESSAGE, 0, MT_MESSAGE, 0) : 0 ;
				this->_msgType = tInform;
				this->_timeToLive = 1;
				this->_actionParam = 0;
        this->_action = sUIAction(0,0,-2);
        this->_clickable = 0;
			} else {
				*this = *msg;
			}
		}
	};

	/** Struktura do przesyania komunikatu rozszerzona o przesyanie informacji dla K.Info (do innych aplikacji)...

  Rozszerzenie komunikatu wywietlania wiadomoci K.Notify o obsug K.Info
	*/
  class sIMessage_notify_kinfo: public sIMessage_notify {
  public:
    const static unsigned int tiStatus = 1; ///< _type - typ komunikatu K.Info
    const static unsigned int tiMessage = 2; ///< _type - typ komunikatu K.Info
    const static unsigned int tiFile = 3; ///< _type - typ komunikatu K.Info
    const static unsigned int tiMail = 4; ///< _type - typ komunikatu K.Info
    const static unsigned int tiURL = 5; ///< _type - typ komunikatu K.Info
  public:
    char *_infoArgs; ///< K.Info - Informacje do przesania @sa SetExtParam
    unsigned int _infoType; ///< K.Info - Typ wiadomoci @sa tiStatus tiMessage tiFile tiMail tiURL
	public:
		/** Przesya wiadomo z identyfikatorem ikonki */
		sIMessage_notify_kinfo(const char * text , unsigned int icoID , const unsigned char msgType = tInform , unsigned char timeToLive = 1)
      :sIMessage_notify(text, icoID, msgType, timeToLive)
      , _infoType(0), _infoArgs(0)
		{
      s_size=sizeof(sIMessage_notify_kinfo);
		}
		/** Przesya wiadomo z uchwytem do ikonki */
    sIMessage_notify_kinfo(const char * text , HICON ico , const unsigned char msgType = tInform , unsigned char timeToLive = 1)
			:sIMessage_notify(text, ico, msgType, timeToLive)
      , _infoType(0), _infoArgs(0)
		{
      s_size=sizeof(sIMessage_notify_kinfo);
		}
		/** Przesya wiadomo jako tInform */
    sIMessage_notify_kinfo(const char * text)
      :sIMessage_notify(text) 
      , _infoType(0), _infoArgs(0)
		{
      s_size=sizeof(sIMessage_notify_kinfo);
    }

	};
}

/** @} */

