/*
 * Konnekt SDK (Software Development Kit)
 * 
 * Nagwek: Plug Export
 * Modyfikowany: 2004-11-02
 * Zgodny z wersj: 
 * Info: Nagwek wymagany w kadej wtyczce (zacza plug.h).
 * 
 * rodowisko: Borland C++ i MS Visual C++
 * 
 * http://www.stamina.eu.org/konnekt/sdk/
 * 
 * (C)2002-2003 Stamina
 * SDK suy do przygotowywania oprogramowania wsppracujcego
 * z programem Konnekt. Autorzy nie ponosz adnej odpowiedzialnoci
 * za wykorzystanie tego kodu.
 * Kod zawarty w SDK moe by uywany tylko w projektach dotyczcych
 * programu Konnekt! */

/**
\file
Nagwek eksportujcy deklaracje funkcji wymagane przez rdze do poprawnej komunikacji.
Od razu importuje plug_shared.h.
Dodatkowo kilka funkcji / makr dla Waszej wygody :)
*/

#ifndef PLUGEXPORTH
#define PLUGEXPORTH

#include "plug.h"
#pragma pack(push, 1)

extern cCtrl * Ctrl;
 /**< Wskaznik do struktury #cCtrl.
                    Przy jej pomocy moliwy jest dostp do funkcji rdzenia.
                    */
/*
Funkcje eksportowane
*/
/**
  Deklaracja jedynej eksportowanej z wtyczki funkcji.
*/
extern "C"
   __declspec(dllexport) int __stdcall IMessageProc(sIMessage_base * msgBase);


/*
  Wszystkie nastepne funkcje sa funkcjami TYLKO pomocniczymi ... Mozna je usunac , ale
najwygodniej jest z nich po prostu korzystac :)
*/


  /**
  \brief Jeeli program dziaa w trybie Debug loguje tre wiadomoci do pliku konnekt.log (i do okna).
  \param format Format dokadnie taki sam jak przy funkcjach printf
  \param parametry Parametry potrzebne do utworzenia wiadomoci

  Funkcja wysya do rdzenia #IMessage #IMC_LOG (ktra nic nie robi, ale jej tre moe zosta zalogowana
  w trybie Debug).
  \attention W trybie \i Debug dostpne jest okno debugowania (IMLOG) w ktrym pokazywana jest tre IMLOG!
  */
  void IMLOG(const char *format, ...);

  /** Wysya IMLOG z komunikatem ostatniego bdu systemu Windows (GetLastError())
  */
  void IMERROR();


  /** Wysya wiadomo . Wywouje bezporednio cCtrl::IMessage .
  \param id Identyfikator wiadomoci
  \param net Docelowa sie wtyczek
  \param type Docelowy typ wtyczek
  \param p1,p2 Parametry
  \sa gr_im net_ imt_
  */
  inline int IMessage(unsigned int  id , signed int net=0 , unsigned int type=-1 , int p1=0 , int p2=0);
  /** Wysya wiadomo . Wywouje bezporednio cCtrl::IMessage .
  */
  inline int IMessage(sIMessage_base * msg);


  /** Wysya wiadomo bezporednio do rdzenia/ui (net = 0 , type = 0) .
  \param id Identyfikator wiadomoci
  \param p1,p2 Parametry
  \sa im_
  */
  inline int ICMessage(unsigned int  id , int p1=0 , int p2=0);

  /** Wysya wiadomo bezporednio do wtyczki.
  \param id Identyfikator wiadomoci
  \param plug ID wtyczki
  \param p1,p2 Parametry
  \sa im_ imc_plug_
  */
  inline int IMessageDirect(unsigned int  id , unsigned int plug=0, int p1=0 , int p2=0);

  /** Wysya wiadomo bezporednio do wtyczki.*/
  inline int IMessageDirect(unsigned int plug , sIMessage_base * msg);


  void WMProcess(void);

// ****************** THREAD SAFE

  /// \defgroup ThreadSafe Makra do przeczania wtkw.
  /// \{


  /** Przeczanie wiadomoci do prawidowych wtkw.
  Jeeli wiadomo zawiera kod , ktry \b MUSI by wykonany
  w gwnym wtku (np. tworzenie okien) mona na pocztku
  kodu akcji wstawi #THREADSAFE. <br>
  Sposb dziaania (wtek "prawidowy" to wtek w ktrym powinna dziaa wiadomo) :
    - Makro sprawdza ID aktualnego wtku
      - Jeeli jest rwne ID \i prawidowego wtku wykonuje dalej...
      - Jeeli jest rne , kolejkuje procedur APC w \i prawidowym
        wtku i oczekuje na zwrcenie wartoci.
  <br><br>
  Przykad:
  \code
   int __stdcall IMessageProc(sIMessage_base * msg) {
     switch (msg->id) {
        case IM_NIEZABEZPIECZANA:
           return 1;
        case IM_ZABEZPIECZANA:
           IMESSAGE_TS();
           // Potencjalnie niebezpieczne operacje...
           return 1;
     }
     if (Ctrl) Ctrl->setError(IMERROR_NORESULT);
                                  // Jeeli wiadomo nie zwraca konkretnego wyniku
                                  // MUSI to zaznaczy!
     return 0;
   }
  \endcode
  \attention Uycie makra jest dozwolone tylko jeeli nie zosta
  jeszcze wykonany \b aden fragment kodu nalecy do wiadomoci. (powinien
  by wstawiony \b od \b razu po \b case IM_...: .
  \attention "Przeczanie" odbywa si poprzez procedury APC (patrz: MSDN)
  Aby nie powiesi caego programu wszystkie zdarzenia oczekujce
  (Sleep , Wait itp.) musz by wykonywane w trybie Alertable
  (SleepEx , Wait...Ex itp.) , tak eby procedura APC moga by wykonana ...
  \attention Jeeli zdaje ci si e wieszasz kolejki APC gwnego wtku
  wcz Test w oknie @Dev...
  */
  #define IMESSAGE_TS() \
    if (Ctrl->Is_TUS(0)) return Ctrl->RecallTS()
  /**
  To samo co #IMESSAGE_TS tyle, e bez oczekiwania na wynik.
  \warning Opcja potencjalnie niebezpieczna. Moe by uywana tylko przy prostych
    wiadomociach, najlepiej nie przechowujcych w swoich parametrach \b adnych
    wskanikw (w momencie gdy wiadomo zostanie przetworzona, wskaniki mog ju
    prowadzi do zwolnionych obszarw pamici).
  */
  #define IMESSAGE_TS_NOWAIT(ret) \
    if (Ctrl->Is_TUS(0)) {Ctrl->RecallTS(0,0);return ret;}


  /// \}

  /**@defgroup gr_cfg Korzystanie z tablic ustawie.
     @{*/
     const char * SAFECHAR(const char * ch);  ///< Sprawdza czy \a ch nie jest == 0. Jeli jest - zwraca pusty cig znakw.
                                                             /// \param ch (char *)
     /**Zwraca warto tekstow z tablicy kontaktw.
     \param row (int) ID kontaktu
     \param id  (int) ID kolumny
     \param buff Bufor do ktrego ma zosta zapisana warto. 
     \param size Rozmiar bufora.
     \return (const char *)
     Jeeli jako \a buff i \a size podamy 0, otrzymamy wskanik do kopii wartoci
     przechowywanej w buforze tymczasowym (cCtrl::GetTempBuff). Jeeli wczeniej
     zablokujemy tablic, otrzymamy najprawdopodobniej wskanik bezporedni.
     Jeeli \a buff bdzie rwny 0, a \a size -1, otrzymamy kopi wartoci
     w wieo zaalokowanej strukturze, ktr naley zwolni przez cCtrl::free.
     \sa #GETCNTCA
     */
     const char * GETCNTC(int row , int id , char * buff = 0 , unsigned int size = 0);
     /**Zwraca warto tekstow (w nowym buforze) z tablicy kontaktw.
     \param row (int) ID kontaktu
     \param id  (int) ID kolumny
     \return (const char *)
     \attention Zwrcony bufor trzeba zwolni przy pomocy cCtrl::free !
     */
     #define GETCNTCA(row , id) GETCNTC(row , id , 0 , -1)


     /**Zwraca warto liczbow (4 bajty) z tablicy kontaktw.
     \param row (int) ID kontaktu
     \param id  (int) ID kolumny
     \return (int)*/
     int GETCNTI(int row , int id);

	 __int64 GETCNTI64(int row , int id);


     /**Ustawia warto tekstow w tablicy kontaktw.
     \param row (int) ID kontaktu
     \param id  (int) ID kolumny
     \param val (char*) warto do ustawienia
     */
     bool SETCNTC(int row , int id , const char * val);
     /**Ustawia warto liczbow (4 bajty) w tablicy kontaktw.
     \param row (int) ID kontaktu
     \param id  (int) ID kolumny
     \param val (int) warto do ustawienia
     \param mask (int) maska ustawianych bitw
     */
     bool SETCNTI(int row , int id , int val, int mask=-1);
     bool SETCNTI64(int row , int id , __int64 val, __int64 mask=-1);
     /**Ustawia warto liczbow (4 bajty) z uyciem maski w tablicy kontaktw.
     \param row (int) ID kontaktu
     \param id  (int) ID kolumny
     \param val (char*) warto do ustawienia
     \param mask (int) Maska, wskazujca ktre bity maj by zmodyfikowane.
     */

     /**Sprawdza czy \a row jest identyfikatorem, czy numerem wiersza.
     \param row (int) warto do sprawdzenia
     \return (bool) true/false
     */
     #define ISCNTID(row) (((row)!=0xFFFFFFFF)&&((row)&DT_ROWID_MASK)) // Sprawdza czy row jest identyfikatorem

     /**Zwraca identyfikator kontaktu.
     \param row (int) Numer wiersza z kontaktem w tablicy (ale moe by te identyfikator)
     \return (int) identyfikator kontaktu.
     */
     #define GETCNTID(row) (ISCNTID(row)?row:Ctrl->DTgetID(DTCNT , (row)))
     /**Zwraca wiersz w tablicy z kontaktem.
     \param row (int) Identyfikator kontaktu (ale moe by te numer wiersza)
     \return (int) Numer wiersza kontaktu.
     */
     #define GETCNTPOS(row) (ISCNTID(row)?Ctrl->DTgetPos(DTCNT , (row)):row)

#ifndef _DTABLE_
    #define DT_ISROWID(row) (((row)!=0xFFFFFFFF)&&((row)&DT_ROWID_MASK)) // Sprawdza czy row jest identyfikatorem
    #define DT_MASKID(row) ((row)|DT_ROWID_MASK)
    #define DT_UNMASKID(row) (row&(~DT_ROWID_MASK)) // Zdejumuje maske z identyfikatora
#endif

     /**Zwraca warto liczbow (4 bajty) z tablicy ustawie.
     \param id  (int) ID kolumny
     \return (int)*/
     int GETINT(int id);
     
     /**Zwraca warto tekstow z tablicy ustawie.
     \param id  (int) ID kolumny
     \param buff Bufor do ktrego ma zosta zapisana warto. 
     \param size Rozmiar bufora.
     \return (const char *)
     Jeeli jako \a buff i \a size podamy 0, otrzymamy wskanik do kopii wartoci
     przechowywanej w buforze tymczasowym (cCtrl::GetTempBuff). Jeeli wczeniej
     zablokujemy tablic, otrzymamy najprawdopodobniej wskanik bezporedni.
     Jeeli \a buff bdzie rwny 0, a \a size -1, otrzymamy kopi wartoci
     w wieo zaalokowanej strukturze, ktr naley zwolni przez cCtrl::free.
     \sa #GETSTRA
     */
     const char * GETSTR(int id , char * buff = 0 , unsigned int size = 0);
     #define GETSTRA(id) GETSTR(id , 0 , -1)
     /**Ustawia warto liczbow (4 bajty) w tablicy ustawie.
     \param id  (int) ID kolumny
     \param val (int) warto
     \param mask (int) maska ustawianych bitw
     */
     bool SETINT(int id , int val , int mask = -1);
     /**Ustawia warto tekstow (char*) w tablicy ustawie.
     \param id  (int) ID kolumny
     \param val (char*) warto
     */
     bool SETSTR(int id , const char * val);

     #ifdef _STRING_
       #define GETCNTS(row , id) (string(GETCNTC(row,id)))
       #define GETSTRING(id)       (string(GETSTR(id)))
     #endif


/** @} */


// *******************************************

  /** Ta funkcja powinna by uyta w #IM_INIT .
  Parametrami s \a p1 i \a p2 przesane razem z #IM_INIT
  */
  int Plug_Init(int p1 , int p2);

  /** Ta funkcja powinna by uyta w #IM_DEINIT .
  Parametrami s \a p1 i \a p2 przesane razem z #IM_DEINIT
  */
  void Plug_Deinit(int p1 , int p2);

// ********************************************
#ifdef __BORLANDC__
#define VSNPRINTF vsnprintf
#else
#define VSNPRINTF _vsnprintf
#endif
#ifdef IMLOG_AUTOALLOC
    char * __vsaprintf(const char *format, va_list ap);
#endif

/** @sa cCtrl::IMLOG() */
void IMLOG(const char *format, ...);
/** @sa cCtrl::IMDEBUG() */
void IMDEBUG(enDebugLevel level , const char *format, ...);

#ifdef _WINDOWS_
 void IMERROR();
#endif


#pragma pack(pop)


#endif
